@@ -7,6 +7,10 @@ import ssl
 import os
 
 import yaml
+try:
+    from yaml import CLoader as Loader
+except ImportError:
+    from yaml import Loader
 from flask import Flask
 from flask import jsonify
 from flask import request
@@ -34,7 +38,7 @@ if 'BIOMAJ_CONFIG' in os.environ:
 
 config = None
 with open(config_file, 'r') as ymlfile:
-    config = yaml.load(ymlfile, Loader=yaml.FullLoader)
+    config = yaml.load(ymlfile, Loader=Loader)
     Utils.service_config_override(config)
 
 
